@@ -1,6 +1,6 @@
 Sys.setenv(NOT_CRAN = "true")
 Sys.setenv(drake_skip_callr = "true")
-options(drake_make_menu = FALSE, drake_clean_menu = FALSE)
+options(drake_clean_menu = FALSE)
 library(testthat)
 devtools::load_all()
 args <- commandArgs(TRUE)
